# -*- coding: iso-8859-15 -*-
irregulars_dictionary = {
    "ir": {
        "indicative": {
            "present": {
                "yo": "voy",
                "tu": "vas",
                "usted": "va",
                "nosotros": "vamos",
                "vosotros": "vais",
                "ustedes": "van",
            },
            "imperfect": {
                "yo": "iba",
                "tu": "ibas",
                "usted": "iba",
                "nosotros": "íbamos",
                "vosotros": "ibais",
                "ustedes": "iban",
            },
            "preterite": {
                "yo": "fui",
                "tu": "fuiste",
                "usted": "fue",
                "nosotros": "fuimos",
                "vosotros": "fuisteis",
                "ustedes": "fueron",
            },
        }
    },
    "ser": {
        "indicative": {
            "present": {
                "yo": "soy",
                "tu": "eres",
                "usted": "es",
                "nosotros": "somos",
                "vosotros": "sois",
                "ustedes": "son",
            },
            "imperfect": {
                "yo": "era",
                "tu": "eras",
                "usted": "era",
                "nosotros": "éramos",
                "vosotros": "erais",
                "ustedes": "eran",
            },
            "preterite": {
                "yo": "fui",
                "tu": "fuiste",
                "usted": "fue",
                "nosotros": "fuimos",
                "vosotros": "fuisteis",
                "ustedes": "fueron",
            },
        }
    },
    "ver": {
        "indicative": {
            "present": {
                "yo": "veo",
                "tu": "ves",
                "usted": "ve",
                "nosotros": "vemos",
                "vosotros": "veis",
                "ustedes": "ven",
            },
            "imperfect": {
                "yo": "veía",
                "tu": "veías",
                "usted": "veía",
                "nosotros": "veíamos",
                "vosotros": "veíais",
                "ustedes": "veían",
            },
            "preterite": {
                "yo": "vi",
                "tu": "vistes",
                "usted": "viste",
                "nosotros": "vimos",
                "vosotros": "visteis",
                "ustedes": "vieron",
            },
        }
    },
}
